import java.awt.image.BufferedImage;
import java.awt.Image;
import java.io.File;
import java.io.IOException;
import java.util.Iterator;
import javax.imageio.ImageIO;
import javax.imageio.ImageReader;
import javax.imageio.metadata.IIOMetadata;
import javax.imageio.metadata.IIOMetadataNode;
import javax.imageio.stream.ImageInputStream;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.Transformer;
import javax.xml.transform.Source;
import javax.xml.transform.Result;
import javax.xml.transform.TransformerConfigurationException;
import javax.xml.transform.TransformerException;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;
import org.w3c.dom.Node;


public class ImageReaderTest10 extends ImageReaderTest1 {
    public ImageReaderTest10(String filename) {
        super(filename);
    }

    protected Image readImage(String filename) { 
        Iterator readers = ImageIO.getImageReadersBySuffix(getSuffix(filename));
        if (readers.hasNext()) {
            ImageReader reader = (ImageReader)readers.next();
            
            try {
                ImageInputStream stream = ImageIO.createImageInputStream(new File(filename));
                reader.setInput(stream);

                IIOMetadata metadata = reader.getImageMetadata(0);
                String[] formatNames = metadata.getMetadataFormatNames();
                for (int i = 0 ; i < formatNames.length ; i++) {
                    System.out.println("Format[" + i + "] = " + formatNames[i]);
                }

                System.out.println("\nNative Metadata Format");
                String formatName = metadata.getNativeMetadataFormatName();
                System.out.println("Native Format Name: " + formatName);
                Node node = metadata.getAsTree(formatName);
                printNode(node);

                System.out.println("\n\nStandard Metadata Format");
                Node standardMetadataNode = metadata.getAsTree("javax_imageio_1.0");
                printNode(standardMetadataNode);

                return reader.read(0);
            } catch (IOException ex) {
                ex.printStackTrace();
            }
        }

        return null;
    }

    private void printNode(Node node) {
        try {
            TransformerFactory factory = TransformerFactory.newInstance();
            Transformer transformer = factory.newTransformer();
        
            Source source = new DOMSource(node);
            Result result = new StreamResult(System.out);
        
            transformer.transform(source, result);
        } catch (TransformerConfigurationException ex) {
            ex.printStackTrace();
        } catch (TransformerException ex) {
            ex.printStackTrace();
        }
    }
    
    public static void main(String[] args) {
        if (args.length == 1) {
            new ImageReaderTest10(args[0]);
        } else {
            System.out.println("Usage: java ImageReaderTest3 <filename>");
        }
    }
}
