import java.awt.image.BufferedImage;
import java.awt.Image;
import java.io.File;
import java.io.IOException;
import java.util.Iterator;
import javax.imageio.IIOImage;
import javax.imageio.ImageIO;
import javax.imageio.ImageReader;
import javax.imageio.stream.ImageInputStream;
import javax.swing.BoxLayout;
import javax.swing.ImageIcon;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;

public class ImageReaderTest11 {
    public ImageReaderTest11(String filename) {
        Iterator images = readImages(filename);
        initFrame(filename, images);
    }

    protected Iterator readImages(String filename) {
        Iterator readers = ImageIO.getImageReadersBySuffix(getSuffix(filename));
        
        if (readers.hasNext()) {
            ImageReader reader = (ImageReader)readers.next();
            
            try {
                ImageInputStream stream = ImageIO.createImageInputStream(new File(filename));
                reader.setInput(stream);

                return reader.readAll(null);
            } catch (IOException ex) {
                ex.printStackTrace();
            }
        }

        return null;
    }
    
    protected void initFrame(String imageName, Iterator images) {
        if (images != null) {
            JFrame frame = new JFrame(imageName);
            frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
            frame.setBounds(100, 100, 600, 600);

            JPanel panel = new JPanel();
            panel.setLayout(new BoxLayout(panel, BoxLayout.Y_AXIS));

            while (images.hasNext()) {
                IIOImage image = (IIOImage)images.next();

                JPanel tmpPanel = new JPanel();
                                
                ImageIcon icon = new ImageIcon((BufferedImage)image.getRenderedImage());
                JLabel label = new JLabel(icon);
                tmpPanel.add(label);

                JLabel thumbnailLabel = null;
                try {
                    BufferedImage thumbnail = image.getThumbnail(0);
                    ImageIcon thumbnailIcon = new ImageIcon(thumbnail);
                    thumbnailLabel = new JLabel(thumbnailIcon);
                } catch (IndexOutOfBoundsException ex) {
                    thumbnailLabel = new JLabel("No Thumbnail");
                }
                 
                tmpPanel.add(thumbnailLabel);
                panel.add(tmpPanel);
            }
        
            frame.getContentPane().add(new JScrollPane(panel));
            frame.setVisible(true);
        }
    }

    protected String getSuffix(String filename) {
        int i = filename.lastIndexOf('.');
        if(i>0 && i<filename.length()-1) {
            return filename.substring(i+1).toLowerCase();
        };
        
        return "";
    }

    public static void main(String[] args) {
        if (args.length == 1) {
            new ImageReaderTest11(args[0]);
        } else {
            System.out.println("Usage: java ImageReaderTest11 <filename>");
        }
    }
}
